# getitdone

### About
Command line to-do list application.

I was browsing on the Internet and wanted a really basic todo list application, which was free and opensource. Since I am in the process of learning more about software development I decided to create my own.


### Installation
```
$ pip install getitdone
```

### Uninstall
```
$ pip uninstall getitdone
```

### Usage
![](https://github.com/ryanleonbutler/getitdone/blob/master/images/image1.jpg?raw=true)



### User Manual
    OPTIONS
        --new or -n '<task-name>'
            Create a new task with name in first argument
        --update or -u '<task-name>' '<new-name>'
            Update task in first argument with value second argument
        --delete or -d '<task-name>'
            Delete task in first argument with value second argument
        --show or -s '<task-name>'
            Delete task in first argument with value second argument
        --help or -h
            Shows man page for todolist

### Report an issue
Create an issue on GitHub with as much supporting information and detail about the bug or issue as possible.

### Contribute
Anyone is welcome to contribute to the project. You can submit your pull request and the changes will be reviewed. When submitting changes, ensure your code is "Pythonic". Use only Stand Library modules. No module are allowed that need further installation.

### License
Licensing is AGPL by default but an MIT license is available for purchase.

### Credits
Duanne Mattheus - Thank you fo providing the name for the application.